@@ -2,7 +2,7 @@
 # encoding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 1, 0)
+__version__ = (0, 1, 1)
 __all__ = [
     "thread_batch", "thread_pool_batch", "async_batch", 
     "threaded", "run_as_thread", "asynchronized", "run_as_async", 
@@ -27,7 +27,7 @@ from threading import Event, Lock, Semaphore, Thread
 from typing import cast, overload, Any, ContextManager, Literal
 
 from argtools import argcount
-from asynctools import async_map, async_zip, run_async
+from asynctools import async_map, async_zip, ensure_coroutine, run_async
 from decotools import optional
 
 
@@ -244,6 +244,7 @@ def asynchronized[**Args, T](
     func: Callable[Args, T], 
     /, 
     loop: None | BaseEventLoop = None, 
+    new_thread: bool = False, 
     executor: Literal[False, None] | Executor = None, 
 ) -> Callable[Args, AsyncFuture[T]]:
     def run_in_thread(loop, future, args, kwargs, /):
@@ -253,8 +254,8 @@ def asynchronized[**Args, T](
             loop.call_soon_threadsafe(future.set_exception, e)
     def wrapper(*args: Args.args, **kwargs: Args.kwargs) -> AsyncFuture[T]:
         nonlocal loop
-        if iscoroutinefunction(func):
-            return ensure_future(func(*args, **kwargs), loop=loop)
+        if not new_thread or iscoroutinefunction(func):
+            return ensure_future(ensure_coroutine(func(*args, **kwargs)), loop=loop)
         if loop is None:
             loop = cast(BaseEventLoop, get_event_loop())
         if executor is False:
